@@ -4,13 +4,13 @@ pairwise.perm.t.test <- function(resp,fact,p.method="fdr",paired=FALSE,
     stop(paste("'",deparse(substitute(resp)),"' and '",deparse(substitute(fact)),
 	"' lengths differ",sep=""))
   }
-  if (!is.numeric(resp)) {resp<-as.numeric(as.character(resp))}
+  if (!is.numeric(resp)) {resp <- as.numeric(as.character(resp))}
   if (!is.factor(fact)) {fact <- factor(fact)}
   if (paired==TRUE & any(diff(tapply(resp,fact,length)))!=0) {
     stop(paste("all levels of ",deparse(substitute(fact))," must have the same length",sep=""))
   }
   if (length(alternative)>1) {alternative <- "two.sided"}
-  data.name <- paste("data: ",deparse(substitute(resp))," and ",deparse(substitute(fact)),sep="")
+  data.name <- paste(deparse(substitute(resp))," and ",deparse(substitute(fact)),"\n",nperm," permutations",sep="")
   method <- if (!paired) {"permutational t tests"} else {"permutational paired t tests"}
   fun.p <- function(i,j) {
     resp2 <- resp[as.numeric(fact)%in%c(i,j)]
@@ -20,15 +20,6 @@ pairwise.perm.t.test <- function(resp,fact,p.method="fdr",paired=FALSE,
   multcomp <- pairwise.table(fun.p,levels(fact),p.adjust.method=p.method)
   result <- list(method=method,data.name=data.name,p.value=multcomp,p.adjust.method=p.method,
     permutations=nperm)
-  class(result) <- c("list","pairwise.perm.t.test")
+  class(result) <- "pairwise.htest"
   return(result)
 }
-
-print.pairwise.perm.t.test <- function (x,...) {
-  cat(paste("\nPairwise comparisons using ",x$method,"\n",sep=""))
-  cat(paste("  (correction: ",x$p.adjust.method,")\n\n",sep=""))
-  cat(x$data.name,"\n")
-  cat(paste(x$permutations," permutations\n",sep=""))
-  print(x$p.value,digits=5,na.print="-")
-  cat("\n")
-}
